==> azure-mgmt-sql-1.3.0-sources.jar: com/microsoft/azure/management/sql/implementation/ReplicationLinkImpl.java <==
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 */

package com.microsoft.azure.management.sql.implementation;

import com.microsoft.azure.management.apigeneration.LangDefinition;
import com.microsoft.azure.management.resources.fluentcore.arm.ResourceId;
import com.microsoft.azure.management.resources.fluentcore.model.implementation.RefreshableWrapperImpl;
import com.microsoft.azure.management.resources.fluentcore.utils.Utils;
import com.microsoft.azure.management.sql.ReplicationLink;
import com.microsoft.azure.management.sql.ReplicationRole;
import com.microsoft.azure.management.sql.ReplicationState;
import com.microsoft.rest.ServiceCallback;
import com.microsoft.rest.ServiceFuture;
import org.joda.time.DateTime;
import rx.Completable;
import rx.Observable;

/**
 * Implementation for SqlServer and its parent interfaces.
 */
@LangDefinition
class ReplicationLinkImpl
        extends RefreshableWrapperImpl<ReplicationLinkInner, ReplicationLink>
        implements ReplicationLink {
    private final DatabasesInner innerCollection;
    private final ResourceId resourceId;

    protected ReplicationLinkImpl(ReplicationLinkInner innerObject, DatabasesInner innerCollection) {
        super(innerObject);
        this.resourceId = ResourceId.fromString(this.inner().id());
        this.innerCollection = innerCollection;
    }

    @Override
    protected Observable<ReplicationLinkInner> getInnerAsync() {
        return this.innerCollection.getReplicationLinkAsync(
                this.resourceGroupName(),
                this.sqlServerName(),
                this.databaseName(),
                this.name());
    }

    @Override
    public String sqlServerName() {
        return resourceId.parent().parent().name();
    }

    @Override
    public String databaseName() {
        return resourceId.parent().name();
    }

    @Override
    public String partnerServer() {
        return this.inner().partnerServer();
    }

    @Override
    public String partnerDatabase() {
        return this.inner().partnerDatabase();
    }

    @Override
    public String partnerLocation() {
        return this.inner().partnerLocation();
    }

    @Override
    public ReplicationRole role() {
        return this.inner().role();
    }

    @Override
    public ReplicationRole partnerRole() {
        return this.inner().partnerRole();
    }

    @Override
    public DateTime startTime() {
        return this.inner().startTime();
    }

    @Override
    public int percentComplete() {
        return Utils.toPrimitiveInt(this.inner().percentComplete());
    }

    @Override
    public ReplicationState replicationState() {
        return this.inner().replicationState();
    }

    @Override
    public void delete() {
        this.innerCollection.deleteReplicationLink(
                this.resourceGroupName(),
                this.sqlServerName(),
                this.databaseName(),
                this.name());
    }

    @Override
    public void failover() {
        this.failoverAsync().await();
    }

    @Override
    public Completable failoverAsync() {
        return this.innerCollection.failoverReplicationLinkAsync(
                this.resourceGroupName(),
                this.sqlServerName(),
                this.databaseName(),
                this.name()).toCompletable();
    }

    @Override
    public ServiceFuture<Void> failoverAsync(ServiceCallback<Void> callback) {
        return ServiceFuture.fromBody(this.failoverAsync().<Void>toObservable(), callback);
    }

    @Override
    public void forceFailoverAllowDataLoss() {
        this.forceFailoverAllowDataLossAsync().await();
    }

    @Override
    public Completable forceFailoverAllowDataLossAsync() {
        return this.innerCollection.failoverReplicationLinkAllowDataLossAsync(
                this.resourceGroupName(),
                this.sqlServerName(),
                this.databaseName(),
                this.name()).toCompletable();
    }

    @Override
    public ServiceFuture<Void> forceFailoverAllowDataLossAsync(ServiceCallback<Void> callback) {
        return ServiceFuture.fromBody(this.forceFailoverAllowDataLossAsync().<Void>toObservable(), callback);
    }

    @Override
    public String name() {
        return this.resourceId.name();
    }

    @Override
    public String id() {
        return this.resourceId.id();
    }

    @Override
    public String resourceGroupName() {
        return this.resourceId.resourceGroupName();
    }
}

==> azure-mgmt-sql-1.24.2-sources.jar: com/microsoft/azure/management/sql/implementation/ReplicationLinkImpl.java <==
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 */
package com.microsoft.azure.management.sql.implementation;

import com.microsoft.azure.management.apigeneration.LangDefinition;
import com.microsoft.azure.management.resources.fluentcore.arm.ResourceId;
import com.microsoft.azure.management.resources.fluentcore.model.implementation.RefreshableWrapperImpl;
import com.microsoft.azure.management.resources.fluentcore.utils.Utils;
import com.microsoft.azure.management.sql.ReplicationLink;
import com.microsoft.azure.management.sql.ReplicationRole;
import com.microsoft.azure.management.sql.ReplicationState;
import com.microsoft.rest.ServiceCallback;
import com.microsoft.rest.ServiceFuture;
import org.joda.time.DateTime;
import rx.Completable;
import rx.Observable;

/**
 * Implementation for SQL replication link interface.
 */
@LangDefinition
class ReplicationLinkImpl
        extends RefreshableWrapperImpl<ReplicationLinkInner, ReplicationLink>
        implements ReplicationLink {

    private final String sqlServerName;
    private final String resourceGroupName;
    private final SqlServerManager sqlServerManager;
    private final ResourceId resourceId;

    protected ReplicationLinkImpl(String resourceGroupName, String sqlServerName, ReplicationLinkInner innerObject, SqlServerManager sqlServerManager) {
        super(innerObject);
        this.resourceGroupName = resourceGroupName;
        this.sqlServerName = sqlServerName;
        this.sqlServerManager = sqlServerManager;
        this.resourceId = ResourceId.fromString(this.inner().id());
    }

    @Override
    protected Observable<ReplicationLinkInner> getInnerAsync() {
        return this.sqlServerManager.inner().replicationLinks()
            .getAsync(this.resourceGroupName,
                this.sqlServerName,
                this.databaseName(),
                this.name());
    }

    @Override
    public String sqlServerName() {
        return this.sqlServerName;
    }

    @Override
    public String databaseName() {
        return this.resourceId.parent().name();
    }

    @Override
    public String partnerServer() {
        return this.inner().partnerServer();
    }

    @Override
    public String partnerDatabase() {
        return this.inner().partnerDatabase();
    }

    @Override
    public String partnerLocation() {
        return this.inner().partnerLocation();
    }

    @Override
    public ReplicationRole role() {
        return this.inner().role();
    }

    @Override
    public ReplicationRole partnerRole() {
        return this.inner().partnerRole();
    }

    @Override
    public DateTime startTime() {
        return this.inner().startTime();
    }

    @Override
    public int percentComplete() {
        return Utils.toPrimitiveInt(this.inner().percentComplete());
    }

    @Override
    public ReplicationState replicationState() {
        return this.inner().replicationState();
    }

    @Override
    public String location() {
        return this.inner().location();
    }

    @Override
    public boolean isTerminationAllowed() {
        return this.inner().isTerminationAllowed();
    }

    @Override
    public String replicationMode() {
        return this.inner().replicationMode();
    }

    @Override
    public void delete() {
        this.sqlServerManager.inner().replicationLinks()
            .delete(this.resourceGroupName,
                this.sqlServerName,
                this.databaseName(),
                this.name());
    }

    @Override
    public void failover() {
        this.sqlServerManager.inner().replicationLinks()
            .failover(this.resourceGroupName,
                this.sqlServerName,
                this.databaseName(),
                this.name());
    }

    @Override
    public Completable failoverAsync() {
        return this.sqlServerManager.inner().replicationLinks()
            .failoverAsync(this.resourceGroupName,
                this.sqlServerName,
                this.databaseName(),
                this.name()).toCompletable();
    }

    @Override
    public ServiceFuture<Void> failoverAsync(ServiceCallback<Void> callback) {
        return ServiceFuture.fromBody(this.failoverAsync(), callback);
    }

    @Override
    public void forceFailoverAllowDataLoss() {
        this.sqlServerManager.inner().replicationLinks()
            .failoverAllowDataLoss(this.resourceGroupName,
                this.sqlServerName,
                this.databaseName(),
                this.name());
    }

    @Override
    public Completable forceFailoverAllowDataLossAsync() {
        return this.sqlServerManager.inner().replicationLinks()
            .failoverAllowDataLossAsync(this.resourceGroupName,
                this.sqlServerName,
                this.databaseName(),
                this.name()).toCompletable();
    }

    @Override
    public ServiceFuture<Void> forceFailoverAllowDataLossAsync(ServiceCallback<Void> callback) {
        return ServiceFuture.fromBody(this.forceFailoverAllowDataLossAsync(), callback);
    }

    @Override
    public String name() {
        return this.inner().name();
    }

    @Override
    public String id() {
        return this.inner().id();
    }

    @Override
    public String resourceGroupName() {
        return this.resourceGroupName;
    }
}
